Module collections

Module collections 

Specialized data structures for optimization algorithms.

Available Structures

  • UnionFind: Disjoint-set forest with path compression and union by rank

Structs

UnionFind
Disjoint-set forest with path compression and union by rank.